import React__default, { createElement, Fragment, Component } from 'react';
import { connect, Provider } from 'react-redux';
import { PersistGate } from 'redux-persist/integration/react';
import { SessionState, UserAgent, Registerer, RegistererState, Inviter, Invitation } from 'sip.js';
import Select from 'react-select';
import Avatar from 'react-avatar';
import { composeWithDevTools } from 'redux-devtools-extension';
import { combineReducers, createStore, applyMiddleware } from 'redux';
import thunk from 'redux-thunk';
import { persistReducer, persistStore } from 'redux-persist';
import storage from 'redux-persist/lib/storage';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _inheritsLoose(subClass, superClass) {
  subClass.prototype = Object.create(superClass.prototype);
  subClass.prototype.constructor = subClass;
  subClass.__proto__ = superClass;
}

function _assertThisInitialized(self) {
  if (self === void 0) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return self;
}

var styles = {"container":"_1H7C6"};

var NEW_USERAGENT = 'NEW_USERAGENT';
var NEW_ACCOUNT = 'NEW_ACCOUNT';
var setNewAccount = function setNewAccount(account) {
  return {
    type: NEW_ACCOUNT,
    payload: account
  };
};

var NEW_SESSION = 'NEW_SESSION';
var NEW_ATTENDED_TRANSFER = 'NEW_ATTENDED_TRANSFER';
var INCOMING_CALL = 'INCOMING_CALL';
var ACCEPT_CALL = 'ACCEPT_CALL';
var DECLINE_CALL = 'DECLINE_CALL';
var SIPSESSION_STATECHANGE = 'SIPSESSION_STATECHANGE';
var CLOSE_SESSION = 'CLOSE_SESSION';
var SIPSESSION_HOLD_REQUEST = 'SIPSESSION_HOLD_REQUEST';
var SIPSESSION_HOLD_FAIL = 'SIPSESSION_HOLD_FAIL';
var SIPSESSION_UNHOLD_REQUEST = 'SIPSESSION_UNHOLD_REQUEST';
var SIPSESSION_UNHOLD_FAIL = 'SIPSESSION_UNHOLD_FAIL';
var SIPSESSION_MUTE_REQUEST = 'SIPSESSION_MUTE_REQUEST';
var SIPSESSION_MUTE_SUCCESS = 'SIPSESSION_MUTE_SUCCESS';
var SIPSESSION_MUTE_FAIL = 'SIPSESSION_MUTE_FAIL';
var SIPSESSION_UNMUTE_REQUEST = 'SIPSESSION_UNMUTE_REQUEST';
var SIPSESSION_UNMUTE_SUCCESS = 'SIPSESSION_UNMUTE_SUCCESS';
var SIPSESSION_UNMUTE_FAIL = 'SIPSESSION_UNMUTE_FAIL';
var SIPSESSION_ATTENDED_TRANSFER_CANCEL = 'SIPSESSION_ATTENDED_TRANSFER_CANCEL';
var SIPSESSION_ATTENDED_TRANSFER_FAIL = 'SIPSESSION_ATTENDED_TRANSFER_FAIL';
var acceptCall = function acceptCall(session) {
  return {
    type: ACCEPT_CALL,
    payload: session
  };
};
var declineCall = function declineCall(session) {
  return {
    type: DECLINE_CALL,
    payload: session
  };
};
var endCall = function endCall(sessionId) {
  return {
    type: CLOSE_SESSION,
    payload: sessionId
  };
};
var holdCallRequest = function holdCallRequest(session) {
  return function (dispatch) {
    if (!session.sessionDescriptionHandler || session.state !== SessionState.Established) {
      return {
        type: SIPSESSION_HOLD_FAIL
      };
    }

    try {
      session.invite({
        sessionDescriptionHandlerModifiers: [session.sessionDescriptionHandler.holdModifier]
      });
      dispatch({
        type: SIPSESSION_HOLD_REQUEST,
        payload: session.id
      });
    } catch (err) {
      dispatch({
        type: SIPSESSION_HOLD_FAIL
      });
    }

    return;
  };
};
var unHoldCallRequest = function unHoldCallRequest(session, onHolds, sessions) {
  return function (dispatch) {
    for (var _i = 0, _Object$entries = Object.entries(sessions); _i < _Object$entries.length; _i++) {
      var _Object$entries$_i = _Object$entries[_i],
          sessionId = _Object$entries$_i[0],
          _session = _Object$entries$_i[1];

      if (onHolds.indexOf(sessionId) < 0 && sessionId !== session.id && _session.state === 'Established') {
        try {
          _session.invite({
            sessionDescriptionHandlerModifiers: [_session.sessionDescriptionHandler.holdModifier]
          });

          dispatch({
            type: SIPSESSION_HOLD_REQUEST,
            payload: _session.id
          });
        } catch (err) {
          dispatch({
            type: SIPSESSION_HOLD_FAIL
          });
        }
      }
    }

    try {
      session.invite();
      dispatch({
        type: SIPSESSION_UNHOLD_REQUEST,
        payload: session.id
      });
    } catch (err) {
      dispatch({
        type: SIPSESSION_UNHOLD_FAIL
      });
    }
  };
};
var muteRequest = function muteRequest() {
  return function (dispatch) {
    dispatch({
      type: SIPSESSION_MUTE_REQUEST
    });
  };
};
var muteSuccess = function muteSuccess() {
  return function (dispatch) {
    dispatch({
      type: SIPSESSION_MUTE_SUCCESS
    });
  };
};
var muteFail = function muteFail() {
  return function (dispatch) {
    dispatch({
      type: SIPSESSION_MUTE_FAIL
    });
  };
};
var unMuteRequest = function unMuteRequest() {
  return function (dispatch) {
    dispatch({
      type: SIPSESSION_UNMUTE_REQUEST
    });
  };
};
var unMuteSuccess = function unMuteSuccess() {
  return function (dispatch) {
    dispatch({
      type: SIPSESSION_UNMUTE_SUCCESS
    });
  };
};
var unMuteFail = function unMuteFail() {
  return function (dispatch) {
    dispatch({
      type: SIPSESSION_UNMUTE_FAIL
    });
  };
};

var SET_CREDENTIALS = 'SET_CREDENTIALS';
var SET_PHONE_CONFIG = 'SET_PHONE_CONFIG';
var SET_APP_CONFIG = 'SET_APP_CONFIG';
var STRICT_MODE_SHOW_CALL_BUTTON = 'STRICT_MODE_SHOW_CALL_BUTTON';
var STRICT_MODE_HIDE_CALL_BUTTON = 'STRICT_MODE_HIDE_CALL_BUTTON';
var SESSIONS_LIMIT_REACHED = 'SESSIONS_LIMIT_REACHED';
var setCredentials = function setCredentials(uri, password) {
  if (uri === void 0) {
    uri = '';
  }

  if (password === void 0) {
    password = '';
  }

  return {
    type: SET_CREDENTIALS,
    payload: {
      uri: uri,
      password: password
    }
  };
};
var setPhoneConfig = function setPhoneConfig(config) {
  return {
    type: SET_PHONE_CONFIG,
    payload: config
  };
};
var setAppConfig = function setAppConfig(config) {
  return {
    type: SET_APP_CONFIG,
    payload: config
  };
};
var setAppConfigStarted = function setAppConfigStarted() {
  return {
    type: STRICT_MODE_SHOW_CALL_BUTTON
  };
};
var sessionsLimitReached = function sessionsLimitReached() {
  return {
    type: SESSIONS_LIMIT_REACHED
  };
};

var holdAll = function holdAll(id) {
  var state = phoneStore.getState();
  var onHolds = state.sipSessions.onHold;
  var sessions = state.sipSessions.sessions;

  for (var _i = 0, _Object$entries = Object.entries(sessions); _i < _Object$entries.length; _i++) {
    var _Object$entries$_i = _Object$entries[_i],
        sessionId = _Object$entries$_i[0],
        session = _Object$entries$_i[1];

    if (onHolds.indexOf(sessionId) < 0 && sessionId !== id) {
      try {
        holdCallRequest(session);
        phoneStore.dispatch({
          type: SIPSESSION_HOLD_REQUEST,
          payload: session.id
        });
        return;
      } catch (err) {
        return;
      }
    }
  }
};

var AUDIO_INPUT_DEVICES_DETECTED = 'AUDIO_INPUT_DEVICES_DETECTED';
var AUDIO_OUTPUT_DEVICES_DETECTED = 'AUDIO_OUTPUT_DEVICES_DETECTED';
var REMOTE_AUDIO_CONNECTED = 'REMOTE_AUDIO_CONNECTED';
var REMOTE_AUDIO_FAIL = 'REMOTE_AUDIO_FAIL';
var LOCAL_AUDIO_CONNECTED = 'LOCAL_AUDIO_CONNECTED';
var SET_PRIMARY_OUTPUT = 'SET_PRIMARY_OUTPUT';
var SET_PRIMARY_INPUT = 'SET_PRIMARY_INPUT';
var SET_LOCAL_AUDIO_SESSIONS_PENDING = 'SET_LOCAL_AUDIO_SESSIONS_PENDING';
var SET_LOCAL_AUDIO_SESSION_SUCCESS = 'SET_LOCAL_AUDIO_SESSION_SUCCESS';
var SET_LOCAL_AUDIO_SESSION_FAIL = 'SET_LOCAL_AUDIO_SESSION_FAIL';
var SET_REMOTE_AUDIO_SESSIONS_PENDING = 'SET_REMOTE_AUDIO_SESSIONS_PENDING';
var SET_REMOTE_AUDIO_SESSION_SUCCESS = 'SET_REMOTE_AUDIO_SESSION_SUCCESS';
var SET_REMOTE_AUDIO_SESSION_FAIL = 'SET_REMOTE_AUDIO_SESSION_FAIL';
var AUDIO_SINKID_NOT_ALLOWED = 'AUDIO_SINKID_NOT_ALLOWED';
var getInputAudioDevices = function getInputAudioDevices() {
  var inputArray = [];
  navigator.mediaDevices.enumerateDevices().then(function (devices) {
    devices.forEach(function (device) {
      if (device.kind === 'audioinput') {
        inputArray.push(device);
      }
    });
  });
  return {
    type: AUDIO_INPUT_DEVICES_DETECTED,
    payload: inputArray
  };
};
var getOutputAudioDevices = function getOutputAudioDevices() {
  var outputArray = [];
  navigator.mediaDevices.enumerateDevices().then(function (devices) {
    devices.forEach(function (device) {
      if (device.kind === 'audiooutput') {
        outputArray.push(device);
      }
    });
  });
  return {
    type: AUDIO_OUTPUT_DEVICES_DETECTED,
    payload: outputArray
  };
};
var setPrimaryOutput = function setPrimaryOutput(deviceId, sessions) {
  return function (dispatch) {
    if (sessions) {
      if (Object.keys(sessions).length > 0) {
        dispatch({
          type: SET_REMOTE_AUDIO_SESSIONS_PENDING
        });

        for (var _i = 0, _Object$entries = Object.entries(sessions); _i < _Object$entries.length; _i++) {
          var _Object$entries$_i = _Object$entries[_i],
              sessionId = _Object$entries$_i[0],
              _session = _Object$entries$_i[1];

          if (_session.state === 'Established') {
            try {
              (function () {
                var mediaElement = document.getElementById(sessionId);
                var remoteStream = new MediaStream();

                _session.sessionDescriptionHandler.peerConnection.getReceivers().forEach(function (receiver) {
                  if (receiver.track) {
                    remoteStream.addTrack(receiver.track);
                  }
                });

                if (mediaElement) {
                  mediaElement.setSinkId(deviceId).then(function () {
                    mediaElement.srcObject = remoteStream;
                    mediaElement.play();
                  });
                } else {
                  console.log('no media Element');
                }
              })();
            } catch (err) {
              console.log(err);
              dispatch({
                type: SET_REMOTE_AUDIO_SESSION_FAIL
              });
              return;
            }
          }

          dispatch({
            type: SET_REMOTE_AUDIO_SESSION_SUCCESS
          });
        }
      }
    }

    dispatch({
      type: SET_PRIMARY_OUTPUT,
      payload: deviceId
    });
  };
};
var setPrimaryInput = function setPrimaryInput(deviceId, sessions, sinkIdAllowed) {
  return function (dispatch) {
    if (sessions) {
      if (Object.keys(sessions).length > 0) {
        dispatch({
          type: SET_LOCAL_AUDIO_SESSIONS_PENDING
        });

        var _loop = function _loop() {
          var _Object$entries2$_i = _Object$entries2[_i2],
              sessionId = _Object$entries2$_i[0],
              _session = _Object$entries2$_i[1];

          if (_session.state === 'Established') {
            try {
              _session.sessionDescriptionHandler.peerConnection.getSenders().forEach(function (sender) {
                console.log(sessionId);

                if (sender.track && sender.track.kind === 'audio') {
                  var audioDeviceId = deviceId;
                  navigator.mediaDevices.getUserMedia({
                    audio: {
                      deviceId: audioDeviceId
                    }
                  }).then(function (stream) {
                    var audioTrack = stream.getAudioTracks();
                    sender.replaceTrack(audioTrack[0]);
                  });
                }
              });
            } catch (err) {
              console.log(err);
              dispatch({
                type: SET_LOCAL_AUDIO_SESSION_FAIL
              });
              return {
                v: void 0
              };
            }
          }

          dispatch({
            type: SET_LOCAL_AUDIO_SESSION_SUCCESS
          });
        };

        for (var _i2 = 0, _Object$entries2 = Object.entries(sessions); _i2 < _Object$entries2.length; _i2++) {
          var _ret = _loop();

          if (typeof _ret === "object") return _ret.v;
        }
      }
    }

    dispatch({
      type: SET_PRIMARY_INPUT,
      payload: deviceId
    });

    if (sinkIdAllowed === false) {
      if (sessions) {
        if (Object.keys(sessions).length > 0) {
          for (var _i3 = 0, _Object$entries3 = Object.entries(sessions); _i3 < _Object$entries3.length; _i3++) {
            var _Object$entries3$_i = _Object$entries3[_i3],
                sessionId = _Object$entries3$_i[0],
                _session = _Object$entries3$_i[1];

            if (_session.state === 'Established') {
              try {
                (function () {
                  var mediaElement = document.getElementById(sessionId);
                  var remoteStream = new MediaStream();

                  _session.sessionDescriptionHandler.peerConnection.getReceivers().forEach(function (receiver) {
                    if (receiver.track) {
                      remoteStream.addTrack(receiver.track);
                    }
                  });

                  if (mediaElement) {
                    mediaElement.srcObject = remoteStream;
                    mediaElement.play();
                  } else {
                    console.log('no media Element');
                  }
                })();
              } catch (err) {
                console.log(err);
                dispatch({
                  type: SET_REMOTE_AUDIO_SESSION_FAIL
                });
                return;
              }
            }

            dispatch({
              type: SET_REMOTE_AUDIO_SESSION_SUCCESS
            });
          }
        }
      }
    }
  };
};

var setRemoteAudio = function setRemoteAudio(session) {
  console.log('setRemoteAudio');
  var state = phoneStore.getState();
  var deviceId = state.device.primaryAudioOutput;
  var mediaElement = document.getElementById(session.id);
  var remoteStream = new MediaStream();
  session.sessionDescriptionHandler.peerConnection.getReceivers().forEach(function (receiver) {
    if (receiver.track.kind === 'audio') {
      remoteStream.addTrack(receiver.track);
    }
  });

  if (mediaElement && typeof mediaElement.sinkId === 'undefined') {
    console.log('safari');
    phoneStore.dispatch({
      type: AUDIO_SINKID_NOT_ALLOWED
    });
    mediaElement.srcObject = remoteStream;
    mediaElement.play();
  } else if (mediaElement && typeof mediaElement.sinkId !== 'undefined') {
    mediaElement.setSinkId(deviceId).then(function () {
      mediaElement.srcObject = remoteStream;
      mediaElement.play();
    });
  } else {
    phoneStore.dispatch({
      type: REMOTE_AUDIO_FAIL
    });
  }

  phoneStore.dispatch({
    type: REMOTE_AUDIO_CONNECTED
  });
};
var setLocalAudio = function setLocalAudio(session) {
  var state = phoneStore.getState();
  var deviceId = state.device.primaryAudioInput;
  session.sessionDescriptionHandler.peerConnection.getSenders().forEach(function (sender) {
    if (sender.track && sender.track.kind === 'audio') {
      var audioDeviceId = deviceId;
      navigator.mediaDevices.getUserMedia({
        audio: {
          deviceId: audioDeviceId
        }
      }).then(function (stream) {
        var audioTrack = stream.getAudioTracks();

        if (audioTrack) {
          sender.replaceTrack(audioTrack[0]);
        }
      });
    }
  });
  phoneStore.dispatch({
    type: LOCAL_AUDIO_CONNECTED
  });
};
var cleanupMedia = function cleanupMedia(sessionId) {
  var mediaElement = document.getElementById(sessionId);

  if (mediaElement) {
    mediaElement.srcObject = null;
    mediaElement.pause();
  }
};

var Tone = require('tone');
var Synth = Tone.PolySynth && new Tone.PolySynth(2, Tone.Synth);
var FMSynth = Tone.PolySynth && new Tone.PolySynth(2, Tone.FMSynth);
var callDisconnect = function callDisconnect(deviceId) {
  FMSynth.triggerAttack(['C4', 'E4'], '+0.1');
  FMSynth.triggerRelease(['C4', 'E4'], '+0.14');
  FMSynth.triggerAttack(['D4', 'G4'], '+0.14');
  FMSynth.triggerRelease(['D4', 'G4'], '+0.18');

  if (deviceId !== 'default') {
    var mediaElement = document.getElementById('tone');

    if (mediaElement) {
      var dest = Tone.context.createMediaStreamDestination();
      Synth.connect(dest);
      mediaElement.setSinkId(deviceId).then(function () {
        mediaElement.srcObject = dest.stream;
        mediaElement.play();
      });
    }
  } else {
    FMSynth.toMaster();
  }
};

var TonePlayer = /*#__PURE__*/function () {
  function TonePlayer() {
    var _this = this;

    this.ringtone = function (deviceId) {
      var mediaElement = document.getElementById('ringtone');

      if (deviceId !== 'default') {
        if (mediaElement) {
          mediaElement.setSinkId(deviceId).then(function () {
            mediaElement.play();
          });
        } else {
          console.log('no media Element');
        }
      } else {
        mediaElement.play();
      }
    };

    this.ringback = function (deviceId) {
      var dest = Tone.context.createMediaStreamDestination();
      console.log(dest);
      Synth.set({
        oscillator: {
          type: 'sine'
        },
        envelope: {
          attack: 0.02,
          decay: 0.1,
          sustain: 0.2,
          release: 0.02
        }
      }).connect(dest);

      if (deviceId !== 'default') {
        var mediaElement = document.getElementById('tone');

        if (mediaElement) {
          var _dest = Tone.context.createMediaStreamDestination();

          Synth.connect(_dest);
          mediaElement.setSinkId(deviceId).then(function () {
            mediaElement.srcObject = _dest.stream;
            mediaElement.play();
          });
        }
      } else {
        Synth.toMaster();
      }

      _this.loop = new Tone.Loop(function (time) {
        Synth.triggerAttack([440, 480]);
        Synth.triggerRelease([440, 480], time + 2);
      }, 6);

      _this.loop.start(0);

      Tone.Transport.start();
    };
  }

  var _proto = TonePlayer.prototype;

  _proto.stop = function stop() {
    if (this.loop) {
      try {
        this.loop.stop(0);
      } catch (_unused) {
        console.log('no loop to stop');
      }
    }

    if (Tone.Transport) {
      try {
        Tone.Transport.stop();
        Synth.triggerRelease([440, 480]);
      } catch (_unused2) {
        console.log('no tone to stop');
      }
    }

    var mediaElement = document.getElementById('ringtone');

    if (mediaElement) {
      var promise = mediaElement.pause();

      if (promise !== undefined) {
        promise.catch(function (error) {
          console.log(error);
        }).then(function () {
          console.log('ringtone stopped');
        });
      }
    }
  };

  return TonePlayer;
}();

var ToneManager = /*#__PURE__*/function () {
  function ToneManager() {}

  var _proto = ToneManager.prototype;

  _proto.playRing = function playRing(type) {
    var state = phoneStore.getState();
    var deviceId = state.device.primaryAudioOutput;

    if (this.currentTone) {
      this.currentTone.stop();
      this.currentTone = undefined;
    }

    if (type === 'ringback') {
      this.currentTone = new TonePlayer();
      this.currentTone.ringback(deviceId);
    } else if (type == 'ringtone') {
      this.currentTone = new TonePlayer();
      this.currentTone.ringtone(deviceId);
    }
  };

  _proto.stopAll = function stopAll() {
    if (this.currentTone) {
      this.currentTone.stop();
      this.currentTone = undefined;
    }
  };

  return ToneManager;
}();

var toneManager = new ToneManager();

var addCallLog = function addCallLog(session, status) {
  var state = phoneStore.getState();
  var uri = session.remoteIdentity.uri.toString();
  console.log('State inside logcall', state);
  var log = {
    clid: session.remoteIdentity.displayName || session.remoteIdentity.uri.user,
    uri: uri,
    time: new Date().getTime(),
    id: session.id,
    status: status
  };
  console.log('session', session);
  console.log('Log', log);
  var callLogs = state.callLogs;

  if (!callLogs.hasOwnProperty(session.id)) {
    callLogs[log.id] = {
      id: log.id,
      clid: log.clid,
      uri: log.uri,
      start: log.time,
      flow: ''
    };
  }

  if (status === 'ended') {
    callLogs[log.id].stop = log.time;
  }

  if (status === 'ended' && callLogs[log.id].status === 'ringing') {
    callLogs[log.id].status = 'missed';
  } else {
    callLogs[log.id].status = status;
  }
};

var SessionStateHandler = function SessionStateHandler(session, ua) {
  var _this = this;

  this.stateChange = function (newState) {
    switch (newState) {
      case SessionState.Establishing:
        holdAll(_this.session.id);
        toneManager.playRing('ringback');
        phoneStore.dispatch({
          type: SIPSESSION_STATECHANGE
        });
        addCallLog(_this.session, SessionState.Establishing);
        var myTransport = _this.ua.transport;
        myTransport.on('message', function (message) {
          if (message.includes('BYE ') && message.indexOf('BYE ') === 0) {
            if (_this.session.state === 'Establishing') {
              console.log(message + " session has recieved a BYE message when the session state is establishing");

              _this.session.cancel();

              _this.session.dispose();

              setTimeout(function () {
                phoneStore.dispatch({
                  type: CLOSE_SESSION,
                  payload: _this.session.id
                });
                toneManager.stopAll();
                phoneStore.dispatch({
                  type: STRICT_MODE_SHOW_CALL_BUTTON
                });
              }, 5000);
              return;
            } else {
              return;
            }
          }
        });
        break;

      case SessionState.Established:
        phoneStore.dispatch({
          type: SIPSESSION_STATECHANGE
        });
        toneManager.stopAll();
        setLocalAudio(_this.session);
        setRemoteAudio(_this.session);
        break;

      case SessionState.Terminating:
        phoneStore.dispatch({
          type: SIPSESSION_STATECHANGE
        });
        toneManager.stopAll();
        cleanupMedia(_this.session.id);
        break;

      case SessionState.Terminated:
        phoneStore.dispatch({
          type: SIPSESSION_STATECHANGE
        });
        setTimeout(function () {
          phoneStore.dispatch({
            type: CLOSE_SESSION,
            payload: _this.session.id
          });
          toneManager.stopAll();
          phoneStore.dispatch({
            type: STRICT_MODE_SHOW_CALL_BUTTON
          });
        }, 5000);
        break;

      default:
        console.log("Unknown session state change: " + newState);
        break;
    }
  };

  this.session = session;
  this.ua = ua;
};
var statusMask = function statusMask(status) {
  switch (status) {
    case 'Established':
      return 'Connected';

    case 'Establishing':
      return 'Calling...';

    case 'Initial':
      return 'Initial';

    case 'Terminating':
    case 'Terminated':
      return 'Ended';

    default:
      return 'Unknown Status';
  }
};
var getDurationDisplay = function getDurationDisplay(duration) {
  var minutes = Math.floor(duration / 60);
  var hours = Math.floor(minutes / 60);
  minutes = minutes % 60;
  var seconds = duration % 60;
  var dh, dm, ds;

  if (hours && hours < 10) {
    dh = "0" + hours + ":";
  } else if (hours) {
    dh = hours + ":";
  } else {
    dh = '00:';
  }

  if (minutes && minutes < 10) {
    dm = "0" + minutes + ":";
  } else if (minutes) {
    dm = minutes + ":";
  } else {
    dm = '00:';
  }

  if (seconds && seconds < 10) {
    ds = "0" + seconds;
  } else if (seconds) {
    ds = "" + seconds;
  } else {
    ds = '00';
  }

  return "" + (hours ? dh : '') + dm + ds;
};

var IncomingSessionStateHandler = function IncomingSessionStateHandler(incomingSession) {
  var _this = this;

  this.stateChange = function (newState) {
    switch (newState) {
      case SessionState.Establishing:
        phoneStore.dispatch({
          type: SIPSESSION_STATECHANGE
        });
        break;

      case SessionState.Established:
        phoneStore.dispatch({
          type: SIPSESSION_STATECHANGE
        });
        holdAll(_this.incomingSession.id);
        setLocalAudio(_this.incomingSession);
        setRemoteAudio(_this.incomingSession);
        break;

      case SessionState.Terminating:
        phoneStore.dispatch({
          type: SIPSESSION_STATECHANGE
        });
        cleanupMedia(_this.incomingSession.id);
        break;

      case SessionState.Terminated:
        phoneStore.dispatch({
          type: SIPSESSION_STATECHANGE
        });
        setTimeout(function () {
          phoneStore.dispatch({
            type: CLOSE_SESSION,
            payload: _this.incomingSession.id
          });
        }, 5000);
        break;

      default:
        console.log("Unknown session state change: " + newState);
        break;
    }
  };

  this.incomingSession = incomingSession;
};

var SIPAccount = /*#__PURE__*/function () {
  function SIPAccount(sipConfig, sipCredentials) {
    var _this = this;

    this._config = sipConfig;
    this._credentials = sipCredentials;
    var uri = UserAgent.makeURI('sip:' + sipCredentials.sipuri);
    console.log('sipaccounts-33', uri);

    if (!uri) {
      throw new Error('Failed to create URI');
    }

    var transportOptions = {
      server: sipConfig.websocket
    };
    console.log('sipaccounts-41', transportOptions);
    var userAgentOptions = {
      authorizationPassword: 'PPovJLibINiTP7owRX',
      transportOptions: transportOptions,
      uri: uri,
      sessionDescriptionHandlerFactoryOptions: {
        constraints: {
          audio: {
            deviceId: 'default'
          },
          video: false
        },
        alwaysAcquireMediaFirst: true,
        iceCheckingTimeout: 500
      }
    };
    var registererOptions = {
      expires: 300,
      logConfiguration: process.env.NODE_ENV !== 'production'
    };
    this._userAgent = new UserAgent(userAgentOptions);
    this._registerer = new Registerer(this._userAgent, registererOptions);
    this.setupDelegate();

    this._userAgent.start().then(function () {
      _this._registerer.register();

      _this.setupRegistererListener();

      console.log('Register', _this._userAgent);
      phoneStore.dispatch({
        type: NEW_USERAGENT,
        payload: _this._userAgent
      });
    });
  }

  var _proto = SIPAccount.prototype;

  _proto.setupDelegate = function setupDelegate() {
    this._userAgent.delegate = {
      onInvite: function onInvite(invitation) {
        var incomingSession = invitation;
        incomingSession.delegate = {
          onRefer: function onRefer(referral) {
            console.log(referral);
          }
        };
        phoneStore.dispatch({
          type: INCOMING_CALL,
          payload: incomingSession
        });
        var stateHandler = new IncomingSessionStateHandler(incomingSession);
        incomingSession.stateChange.addListener(stateHandler.stateChange);
      }
    };
  };

  _proto.setupRegistererListener = function setupRegistererListener() {
    this._registerer.stateChange.addListener(function (newState) {
      switch (newState) {
        case RegistererState.Initial:
          console.log('The user registration has initialized  ');
          break;

        case RegistererState.Registered:
          console.log('The user is registered ');
          break;

        case RegistererState.Unregistered:
          console.log('The user is unregistered ');
          break;

        case RegistererState.Terminated:
          console.log('The user is terminated ');
          break;
      }
    });
  };

  _proto.makeCall = function makeCall(number) {
    var state = phoneStore.getState();
    console.log('makCall', state);
    var sessionsLimit = state.config.phoneConfig.sessionsLimit;
    var sessionsActiveObject = state.sipSessions.sessions;
    var strictMode = state.config.appConfig.mode;
    var attendedTransfersActive = 0;
    var sessionsActive = Object.keys(sessionsActiveObject).length;
    var sessionDiff = sessionsActive - attendedTransfersActive;

    if (sessionDiff >= sessionsLimit) {
      phoneStore.dispatch({
        type: SESSIONS_LIMIT_REACHED
      });
    } else {
      var target = UserAgent.makeURI("sip:" + number + "@" + this._credentials.sipuri.split('@')[1]);
      console.log('sipaccount-151', target);

      if (strictMode === 'strict') {
        phoneStore.dispatch({
          type: STRICT_MODE_HIDE_CALL_BUTTON
        });
      }

      if (target) {
        console.log("Calling " + number);
        var inviter = new Inviter(this._userAgent, target);
        var outgoingSession = inviter;
        outgoingSession.delegate = {
          onRefer: function onRefer(referral) {
            console.log('Referred: ' + referral);
          }
        };
        phoneStore.dispatch({
          type: NEW_SESSION,
          payload: outgoingSession
        });
        var stateHandler = new SessionStateHandler(outgoingSession, this._userAgent);
        outgoingSession.stateChange.addListener(stateHandler.stateChange);
        outgoingSession.invite().then(function () {
          console.log('Invite sent!');
          console.log('outgoing session', outgoingSession);
        }).catch(function (error) {
          console.log(error);
        });
      } else {
        console.log("Failed to establish outgoing call session to " + number);
      }
    }
  };

  _proto.listener = function listener() {};

  return SIPAccount;
}();

var SipWrapper = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(SipWrapper, _React$Component);

  function SipWrapper() {
    return _React$Component.apply(this, arguments) || this;
  }

  var _proto = SipWrapper.prototype;

  _proto.componentDidMount = function componentDidMount() {
    console.log('mounted');

    if (this.props.sipCredentials.password) {
      this.initializeSip();
    }
  };

  _proto.initializeSip = function initializeSip() {
    var account = new SIPAccount(this.props.sipConfig, this.props.sipCredentials);
    this.props.setNewAccount(account);
    this.props.setPhoneConfig(this.props.phoneConfig);
    this.props.setAppConfig(this.props.appConfig);
  };

  _proto.render = function render() {
    return createElement(Fragment, null, this.props.children);
  };

  return SipWrapper;
}(Component);

var mapStateToProps = function mapStateToProps() {
  return {};
};

var actions = {
  setNewAccount: setNewAccount,
  setPhoneConfig: setPhoneConfig,
  setCredentials: setCredentials,
  setAppConfig: setAppConfig
};
var SipWrapper$1 = connect(mapStateToProps, actions)(SipWrapper);

var styles$1 = {"container":"_Adysl","incoming":"_14y58","dialpad":"_24i7u","closed":"_3nIZK","statusLarge":"_3G14Z","dialpadButton":"_38DZj","dialpadButtonLetters":"_N-jqm","dialpadRow":"_19SxG","actionButton":"_1hhhF","on":"_3ZwLv","endCallButton":"_3z8u3","startCallButton":"_3UW76","actionsContainer":"_2kDeL","transferMenu":"_1yjIy","transferInput":"_2tho8","transferButtons":"_Rc_m0","userString":"_gelBY","userStringLarge":"_rgh4W","settingsButton":"_3TfJl","settingsMenu":"_6JtnT","dropdowns":"_2FMhO","dropdownRow":"_2NuIJ","dropdownIcon":"_1K5Gw"};

var settingsIcon = require('./assets/settings-24px.svg');

var micIcon = require('./assets/mic-24px.svg');

var soundIcon = require('./assets/volume_up-24px.svg');

var Status = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(Status, _React$Component);

  function Status() {
    var _this;

    _this = _React$Component.apply(this, arguments) || this;
    _this.state = {
      settingsMenu: false
    };
    return _this;
  }

  var _proto = Status.prototype;

  _proto.componentDidMount = function componentDidMount() {
    this.props.getInputAudioDevices();
    this.props.getOutputAudioDevices();
  };

  _proto.mapOptions = function mapOptions(options) {
    var list = [];
    options.map(function (option) {
      list.push({
        value: option.deviceId,
        label: option.label
      });
    });
    return list;
  };

  _proto.handleChangeDevice = function handleChangeDevice(type, id) {
    if (type === 'out') {
      this.props.setPrimaryOutput(id, this.props.sessions);
    } else {
      this.props.setPrimaryInput(id, this.props.sessions, this.props.sinkIdAllowed);
    }
  };

  _proto.render = function render() {
    var _this2 = this;

    var props = this.props,
        state = this.state;
    var inputs = this.mapOptions(props.inputs);
    var outputs = this.mapOptions(props.outputs);
    return createElement(Fragment, null, createElement("div", {
      className: styles$1.container
    }, props.appConfig.appSize === 'large' ? createElement("div", {
      className: styles$1.userStringLarge
    }, props.name) : createElement("div", {
      className: styles$1.userString
    }, props.name), props.phoneConfig.disabledFeatures.includes('settings') ? null : createElement("div", {
      id: styles$1.settingsButton,
      className: state.settingsMenu ? styles$1.on : '',
      onClick: function onClick() {
        return _this2.setState({
          settingsMenu: !state.settingsMenu
        });
      }
    }, createElement("img", {
      src: settingsIcon,
      className: "settingsIcon"
    }))), props.phoneConfig.disabledFeatures.includes('settings') ? null : createElement("div", {
      id: styles$1.settingsMenu,
      className: state.settingsMenu ? '' : styles$1.closed
    }, createElement("hr", {
      style: {
        width: '100%'
      }
    }), createElement("div", {
      className: styles$1.dropdownRow
    }, createElement("img", {
      className: styles$1.dropdownIcon,
      src: soundIcon
    }), createElement(Select, {
      placeholder: 'Select Output...',
      value: outputs.find(function (output) {
        return output.value === props.primaryOutput;
      }) || null,
      onChange: function onChange(option) {
        return _this2.handleChangeDevice('out', option.value);
      },
      options: outputs,
      id: styles$1.dropdowns
    })), createElement("div", {
      className: styles$1.dropdownRow
    }, createElement("img", {
      className: styles$1.dropdownIcon,
      src: micIcon
    }), createElement(Select, {
      placeholder: 'Select Input...',
      value: inputs.find(function (input) {
        return input.value === props.primaryInput;
      }),
      onChange: function onChange(option) {
        return _this2.handleChangeDevice('in', option.value);
      },
      options: inputs,
      id: styles$1.dropdowns
    })), createElement("hr", {
      style: {
        width: '100%'
      }
    })));
  };

  return Status;
}(Component);

var mapStateToProps$1 = function mapStateToProps(state) {
  return {
    inputs: state.device.audioInput,
    outputs: state.device.audioOutput,
    primaryInput: state.device.primaryAudioInput,
    primaryOutput: state.device.primaryAudioOutput,
    sessions: state.sipSessions.sessions,
    sinkIdAllowed: state.device.sinkId
  };
};

var actions$1 = {
  setPrimaryInput: setPrimaryInput,
  setPrimaryOutput: setPrimaryOutput,
  getInputAudioDevices: getInputAudioDevices,
  getOutputAudioDevices: getOutputAudioDevices
};
var Status$1 = connect(mapStateToProps$1, actions$1)(Status);

var Hold = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(Hold, _React$Component);

  function Hold() {
    return _React$Component.apply(this, arguments) || this;
  }

  var _proto = Hold.prototype;

  _proto.hold = function hold() {
    if (this.checkHoldState()) {
      this.props.unHoldCallRequest(this.props.session, this.props.onHold, this.props.sessions);
    } else {
      this.props.holdCallRequest(this.props.session);
    }
  };

  _proto.checkHoldState = function checkHoldState() {
    return this.props.onHold.includes(this.props.session.id);
  };

  _proto.render = function render() {
    var _this = this;

    return createElement("li", {
      className: this.checkHoldState() ? 'active' : ''
    }, createElement("a", {
      href: 'javascript:void(0)',
      onClick: function onClick() {
        return _this.hold();
      }
    }, createElement("span", {
      className: 'fa-icon rv-pause'
    })));
  };

  return Hold;
}(Component);

var mapStateToProps$2 = function mapStateToProps(state) {
  return {
    stateChanged: state.sipSessions.stateChanged,
    sessions: state.sipSessions.sessions,
    userAgent: state.sipAccounts.userAgent,
    onHold: state.sipSessions.onHold
  };
};

var actions$2 = {
  holdCallRequest: holdCallRequest,
  unHoldCallRequest: unHoldCallRequest
};
var Hold$1 = connect(mapStateToProps$2, actions$2)(Hold);

var Mute = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(Mute, _React$Component);

  function Mute() {
    var _this;

    _this = _React$Component.apply(this, arguments) || this;
    _this.state = {
      onMute: false
    };
    return _this;
  }

  var _proto = Mute.prototype;

  _proto.mute = function mute() {
    var _this2 = this;

    console.log('inside mute');

    if (this.state.onMute) {
      this.props.unMuteRequest();
      return new Promise(function (resolve, reject) {
        if (!_this2.props.session.sessionDescriptionHandler || _this2.props.session.state !== SessionState.Established) {
          _this2.props.unMuteFail();

          reject('No session to mute');
          return;
        }

        try {
          var pc = _this2.props.session.sessionDescriptionHandler.peerConnection;
          pc.getSenders().forEach(function (stream) {
            if (stream.track && stream.track.kind === 'audio') {
              stream.track.enabled = true;
            }
          });

          _this2.props.unMuteSuccess();

          _this2.setState({
            onMute: false
          });

          resolve();
          return;
        } catch (err) {
          _this2.props.unMuteFail();

          reject(err);
        }
      });
    }

    if (!this.state.onMute) {
      return new Promise(function (resolve, reject) {
        if (!_this2.props.session.sessionDescriptionHandler || _this2.props.session.state !== SessionState.Established) {
          _this2.props.muteFail();

          reject('No session to mute');
          return;
        }

        try {
          _this2.props.muteRequest();

          var pc = _this2.props.session.sessionDescriptionHandler.peerConnection;
          console.log(pc.getSenders());
          pc.getSenders().forEach(function (stream) {
            if (stream.track && stream.track.kind === 'audio') {
              stream.track.enabled = false;
            }
          });

          _this2.props.muteSuccess();

          _this2.setState({
            onMute: true
          });

          resolve();
          return;
        } catch (err) {
          _this2.props.muteFail();

          reject(err);
          return;
        }
      });
    }

    this.props.muteFail();
    return;
  };

  _proto.render = function render() {
    var _this3 = this;

    return createElement("li", {
      className: this.state.onMute ? 'active' : ''
    }, createElement("a", {
      href: 'javascript:void(0)',
      onClick: function onClick() {
        return _this3.mute();
      }
    }, createElement("span", {
      className: 'fa-icon rv-microphone'
    })));
  };

  return Mute;
}(Component);

var mapStateToProps$3 = function mapStateToProps(state) {
  return {
    stateChanged: state.sipSessions.stateChanged,
    sessions: state.sipSessions.sessions,
    userAgent: state.sipAccounts.userAgent
  };
};

var actions$3 = {
  muteRequest: muteRequest,
  muteSuccess: muteSuccess,
  muteFail: muteFail,
  unMuteRequest: unMuteRequest,
  unMuteSuccess: unMuteSuccess,
  unMuteFail: unMuteFail
};
var Mute$1 = connect(mapStateToProps$3, actions$3)(Mute);

var styles$2 = {"container":"_33s4p","incoming":"_3dASG","dialpad":"_-iUpI","closed":"_1Yn0M","statusLarge":"_3n9O3","dialpadButton":"_2Mev0","dialpadButtonLetters":"_30C7x","dialpadRow":"_ftZ8R","actionButton":"_1gnBl","on":"_11LDZ","endCallButton":"_EoCL2","startCallButton":"_PaJuy","actionsContainer":"_25gV2","transferMenu":"_1yYD-","transferInput":"_ovMXl","transferButtons":"_1-bn8"};

var VolumeControl = /*#__PURE__*/function (_Component) {
  _inheritsLoose(VolumeControl, _Component);

  function VolumeControl(props) {
    var _this;

    _this = _Component.call(this, props) || this;
    _this.state = {
      volume: 100,
      showDropdown: false,
      showHeadphoneDropdown: false
    };

    _this.onClickDropdown = function () {
      _this.setState({
        showDropdown: !_this.state.showDropdown
      });
    };

    _this.onClickHeadphoneDropdown = function () {
      console.log('called in headphone');

      _this.setState({
        showHeadphoneDropdown: !_this.state.showHeadphoneDropdown
      });
    };

    _this.handleClickDropdown = function (e) {
      if (_this.dropdownRef.current && !_this.dropdownRef.current.contains(e.target)) {
        _this.setState({
          showDropdown: false
        });
      }
    };

    _this.handleClickDropdownHeadphone = function (e) {
      if (_this.headPhoneDropdownRef.current && !_this.headPhoneDropdownRef.current.contains(e.target)) {
        _this.setState({
          showHeadphoneDropdown: false
        });
      }
    };

    _this.handleVolumeChange = _this.handleVolumeChange.bind(_assertThisInitialized(_this));
    _this.dropdownRef = React__default.createRef();
    _this.headPhoneDropdownRef = React__default.createRef();
    return _this;
  }

  var _proto = VolumeControl.prototype;

  _proto.componentDidMount = function componentDidMount() {
    this.props.getInputAudioDevices();
    this.props.getOutputAudioDevices();
  };

  _proto.handleVolumeChange = function handleVolumeChange(e) {
    this.setState({
      volume: e.target.value
    });
  };

  _proto.handleChangeDevice = function handleChangeDevice(type, id) {
    if (type === 'out') {
      this.props.setPrimaryOutput(id, this.props.sessions);
    }
  };

  _proto.render = function render() {
    var _this$props$audioOutp,
        _this2 = this;

    return React__default.createElement(React__default.Fragment, null, React__default.createElement("div", {
      className: 'volume-headphone'
    }, React__default.createElement("div", {
      className: this.state.showDropdown ? 'dropdown volume-dropdown show' : 'dropdown volume-dropdown'
    }, console.log({
      state: this.state.showDropdown
    }), React__default.createElement("button", {
      className: 'dropdown-toggle',
      type: 'button',
      id: 'dropdownMenuButton',
      "data-toggle": 'dropdown',
      "aria-haspopup": 'true',
      "aria-expanded": 'false'
    }, React__default.createElement("div", {
      className: 'icon-box'
    }, React__default.createElement("span", {
      onClick: this.onClickDropdown,
      className: 'fa-icon rv-speaker'
    }))), React__default.createElement("div", {
      ref: this.dropdownRef,
      className: this.state.showDropdown ? 'dropdown-menu dropdown-menu-right show' : 'dropdown-menu dropdown-menu-right',
      "aria-labelledby": 'dropdownMenuButton'
    }, React__default.createElement("div", {
      className: 'range-slider'
    }, React__default.createElement("input", {
      ref: 'slider',
      max: 100,
      min: 0,
      type: 'range',
      step: 5,
      value: this.state.volume,
      onChange: this.handleVolumeChange
    })))), React__default.createElement("div", {
      className: this.state.showHeadphoneDropdown ? "dropdown headphone-dropdown show" : "dropdown headphone-dropdown"
    }, React__default.createElement("button", {
      className: 'dropdown-toggle',
      type: 'button',
      id: 'dropdownMenuButton',
      "data-toggle": 'dropdown',
      "aria-haspopup": 'true',
      "aria-expanded": 'false',
      onClick: this.onClickHeadphoneDropdown
    }, React__default.createElement("div", {
      className: 'icon-box'
    }, React__default.createElement("span", {
      onClick: this.onClickHeadphoneDropdown,
      className: 'fa-icon rv-headphones'
    }))), React__default.createElement("div", {
      ref: this.headPhoneDropdownRef,
      className: this.state.showHeadphoneDropdown ? "dropdown-menu dropdown-menu-right show" : "dropdown-menu dropdown-menu-right",
      "aria-labelledby": 'dropdownMenuButton',
      id: 'selectDevice'
    }, (_this$props$audioOutp = this.props.audioOutputs) === null || _this$props$audioOutp === void 0 ? void 0 : _this$props$audioOutp.map(function (audio) {
      return React__default.createElement("a", {
        key: audio.deviceId,
        onClick: function onClick(e) {
          e.preventDefault();

          _this2.handleChangeDevice('out', audio.deviceId);
        },
        className: 'dropdown-item',
        href: '#'
      }, React__default.createElement("span", {
        className: 'fa-icon rv-headphones'
      }), audio === null || audio === void 0 ? void 0 : audio.label);
    })))));
  };

  return VolumeControl;
}(Component);

var mapStateToProps$4 = function mapStateToProps(state) {
  return {
    audioOutputs: state.device.audioOutput,
    setPrimaryOutput: state.device.setPrimaryOutput,
    sessions: state.sipSessions.sessions,
    sinkIdAllowed: state.device.sinkId
  };
};

var actions$4 = {
  setPrimaryInput: setPrimaryInput,
  setPrimaryOutput: setPrimaryOutput,
  getInputAudioDevices: getInputAudioDevices,
  getOutputAudioDevices: getOutputAudioDevices
};
var VoumeControl = connect(mapStateToProps$4, actions$4)(VolumeControl);

var Phone = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(Phone, _React$Component);

  function Phone(props) {
    var _this;

    _this = _React$Component.call(this, props) || this;
    _this.state = {
      dialpadOpen: false,
      transferMenu: false,
      ended: false,
      transferDialString: '',
      attendedTransferStarted: false,
      duration: 0,
      counterStarted: false
    };
    _this.attendedProcess = _this.attendedProcess.bind(_assertThisInitialized(_this));
    return _this;
  }

  var _proto = Phone.prototype;

  _proto.componentDidMount = function componentDidMount() {
    if (this.props.phoneConfig.disabledButtons.includes('dialpadopen')) {
      this.setState({
        dialpadOpen: true
      });
    }
  };

  _proto.componentDidUpdate = function componentDidUpdate(newProps) {
    if (newProps.session.state === SessionState.Established && !this.state.counterStarted) {
      this.handleCounter();
    }

    if (newProps.session.state === SessionState.Terminated && this.state.ended === false) {
      this.setState({
        ended: true
      });
    }
  };

  _proto.endCall = function endCall() {
    var _this2 = this;

    console.log('session', this.props.session.remoteIdentity);

    if (this.props.session.state === SessionState.Established) {
      this.props.session.bye();
    } else if (this.props.session.state === SessionState.Initial || this.props.session.state === SessionState.Establishing) {
      toneManager.stopAll();
      callDisconnect(this.props.deviceId);
      this.props.session.cancel();
    }

    this.setState({
      ended: true
    });

    if (this.props.phoneConfig.functions !== undefined) {
      this.props.phoneConfig.functions();
    }

    setTimeout(function () {
      _this2.props.session.dispose();

      _this2.props.endCall(_this2.props.session.id);

      if (_this2.props.strictMode === 'strict') {
        _this2.props.setAppConfigStarted();
      }
    }, 5000);
  };

  _proto.attendedProcess = function attendedProcess(bool) {
    this.setState({
      attendedTransferStarted: bool
    });
  };

  _proto.handleCounter = function handleCounter() {
    var _this3 = this;

    if (this.props.session && this.props.session.state !== SessionState.Terminated) {
      if (this.state.counterStarted === false) {
        this.setState({
          counterStarted: true
        });
      }

      setTimeout(function () {
        _this3.setState({
          duration: _this3.state.duration + 1
        });

        _this3.handleCounter();
      }, 1000);
    }
  };

  _proto.render = function render() {
    var _this4 = this;

    var state = this.state,
        props = this.props;
    var isIncomingCall = props.session instanceof Invitation;
    var durationDisplay;

    if (props.appSize === 'large') {
      if (this.props.session.state === SessionState.Initial || this.props.session.state === SessionState.Establishing) {
        durationDisplay = null;
      } else {
        durationDisplay = createElement("div", {
          className: styles$2.statusLarge
        }, getDurationDisplay(this.state.duration));
      }
    } else {
      if (this.props.session.state === SessionState.Initial || this.props.session.state === SessionState.Establishing) {
        durationDisplay = null;
      } else {
        durationDisplay = createElement("div", null, getDurationDisplay(this.state.duration));
      }
    }

    return createElement(Fragment, null, state.ended ? null : createElement(Fragment, null, !isIncomingCall && createElement(Fragment, null, createElement("div", {
      className: 'voicemail-sec__options'
    }, createElement("div", {
      className: 'voicemail-sec__options-main'
    }, createElement("span", null, statusMask(props.session.state)), createElement("ul", {
      className: 'list-unstyled mb-0'
    }, createElement("li", null, createElement("a", {
      href: '#'
    }, durationDisplay)), createElement("li", null, createElement("a", {
      href: '#'
    }, createElement("span", {
      className: 'fa-icon rv-warning'
    }))), createElement("li", null, createElement("a", {
      href: '#'
    }, createElement("span", {
      className: 'fa-icon rv-sound-wave'
    }))))), createElement("input", {
      type: 'tel',
      className: 'form-control',
      value: '+91'
    })), createElement("div", {
      className: 'voicemail-sec__control'
    }, createElement("ul", {
      className: 'list-unstyled mb-0'
    }, createElement(Mute$1, {
      session: props.session
    }), createElement(Hold$1, {
      session: props.session
    }), createElement("li", null, createElement("a", {
      href: '#'
    }, createElement("span", {
      className: 'fa-icon rv-miscall'
    }))), createElement("li", null, createElement("a", {
      href: '#'
    }, createElement("span", {
      className: 'fa-icon rv-video-camera'
    })))), createElement("ul", {
      className: 'list-unstyled mb-0'
    }, createElement("li", {
      className: 'more-detail'
    }, createElement("div", {
      className: 'dropdown volume-dropdown'
    }, createElement("button", {
      className: 'dropdown-toggle',
      type: 'button',
      id: 'dropdownMenuButton',
      "data-toggle": 'dropdown',
      "aria-haspopup": 'true',
      "aria-expanded": 'false'
    }, createElement("div", {
      className: 'icon-box'
    }, createElement("span", {
      className: 'fa-icon rv-more'
    }))), createElement("div", {
      className: 'dropdown-menu dropdown-menu-right',
      "aria-labelledby": 'dropdownMenuButton'
    }))), createElement("li", {
      className: 'end-call'
    }, createElement("a", {
      href: '#',
      onClick: function onClick() {
        return _this4.endCall();
      }
    }, createElement("span", {
      className: 'fa-icon rv-phone-down'
    }))))), createElement("audio", {
      id: this.props.session.id,
      autoPlay: true
    }), createElement(VoumeControl, null)), isIncomingCall && createElement(Fragment, null, createElement("div", {
      className: 'modal fade callui-popup fadeIn show',
      id: 'callui',
      tabIndex: -1,
      role: 'dialog',
      "aria-labelledby": 'exampleModalLabel',
      "aria-hidden": 'true',
      style: {
        display: 'block'
      }
    }, createElement("div", {
      className: 'modal-dialog',
      role: 'document'
    }, createElement("div", {
      className: 'modal-content'
    }, createElement("div", {
      className: 'modal-body p-0'
    }, createElement("div", {
      className: 'callui-popup__main d-flex'
    }, createElement("div", {
      className: 'callui-popup__main-left'
    }, createElement("div", {
      className: 'callui-personDetail'
    }, createElement("h3", {
      className: 'personName'
    }, props.phoneConfig.displayName, createElement("span", {
      className: 'd-block mt-2'
    }, durationDisplay)), createElement("div", {
      className: 'closeBtns'
    }, createElement("a", {
      href: '#'
    }, createElement("span", {
      className: 'fa-icon rv-link'
    })), createElement("a", {
      href: '#'
    }, createElement("span", {
      className: 'fa-icon rv-close'
    })))), createElement("div", {
      className: 'callui-personJoin'
    }, createElement("div", {
      className: 'row'
    }, createElement("div", {
      className: 'col-md-6'
    }, createElement("div", {
      className: 'callui-personJoin__block'
    }, createElement("span", null, createElement(Avatar, {
      name: props.phoneConfig.displayName,
      round: true
    })))), createElement("div", {
      className: 'col-md-6'
    }, createElement("div", {
      className: 'callui-personJoin__block'
    }, createElement("span", null, createElement(Avatar, {
      name: props.session.remoteIdentity.displayName,
      round: true
    })))))), createElement("ul", {
      className: 'list-unstyled callui-controls mb-0 mt-5'
    }, createElement(Mute$1, {
      session: props.session
    }), createElement("li", null, createElement("a", {
      href: 'javascript:void(0)',
      onClick: function onClick() {
        return _this4.endCall();
      }
    }, createElement("span", {
      className: 'fa-icon rv-phone-down'
    }))), createElement("li", null, createElement("a", {
      href: '#'
    }, createElement("span", {
      className: 'fa-icon rv-speaker'
    }))))), createElement("div", {
      className: 'callui-popup__main-right'
    }, createElement("div", {
      className: 'calluiBtns'
    }, createElement("a", {
      href: '#',
      className: 'mb-4 create-reminder'
    }, "Create a reminder"), createElement("a", {
      href: '#',
      className: 'create-task'
    }, "Create a Task")), createElement("div", {
      className: 'pending-task'
    }, createElement("h5", null, "Pending Tasks"), createElement("ul", {
      className: 'list-unstyled contact-details'
    }, createElement("li", null, createElement("div", {
      className: 'icon-box'
    }, ' ', createElement("span", {
      className: 'fa-icon rv-user'
    })), createElement("div", {
      className: 'contact-details__list'
    }, createElement("label", {
      className: 'heading-4'
    }, "Documents Submitted"), ' ', createElement("span", {
      className: 'detail-value'
    }, "29th Nov 2020, Friday, 4:25 PM"))), createElement("li", null, createElement("div", {
      className: 'icon-box'
    }, ' ', createElement("span", {
      className: 'fa-icon rv-user'
    })), createElement("div", {
      className: 'contact-details__list'
    }, createElement("label", {
      className: 'heading-4'
    }, "Delivery order received"), ' ', createElement("span", {
      className: 'detail-value'
    }, "04th Dec 2020, Friday, 05:25 PM"))), createElement("li", null, createElement("div", {
      className: 'icon-box'
    }, ' ', createElement("span", {
      className: 'fa-icon rv-service'
    })), createElement("div", {
      className: 'contact-details__list'
    }, createElement("label", {
      className: 'heading-4'
    }, "Email sent"), ' ', createElement("span", {
      className: 'detail-value'
    }, "29th Nov 2020, Friday, 4:25 PM"))), createElement("li", null, createElement("div", {
      className: 'icon-box'
    }, ' ', createElement("span", {
      className: 'fa-icon rv-packages'
    })), createElement("div", {
      className: 'contact-details__list'
    }, createElement("label", {
      className: 'heading-4'
    }, "Delivery order received"), ' ', createElement("span", {
      className: 'detail-value'
    }, "04th Dec 2020, Friday, 05:25 PM"))))))))))))));
  };

  return Phone;
}(Component);

var mapStateToProps$5 = function mapStateToProps(state) {
  return {
    stateChanged: state.sipSessions.stateChanged,
    sessions: state.sipSessions.sessions,
    userAgent: state.sipAccounts.userAgent,
    deviceId: state.device.primaryAudioOutput,
    strictMode: state.config.appConfig.mode,
    appSize: state.config.appConfig.appSize
  };
};

var actions$5 = {
  endCall: endCall,
  setAppConfigStarted: setAppConfigStarted
};
var Phone$1 = connect(mapStateToProps$5, actions$5)(Phone);

var ring = require('./assets/ring.mp3');

var Incoming = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(Incoming, _React$Component);

  function Incoming() {
    return _React$Component.apply(this, arguments) || this;
  }

  var _proto = Incoming.prototype;

  _proto.componentDidMount = function componentDidMount() {
    var _this = this;

    toneManager.stopAll();
    toneManager.playRing('ringtone');
    console.log("auto-answer is: " + this.props.autoanswer);

    if (this.props.autoanswer) {
      this.timer = setInterval(function () {
        _this.handleAutoAnswer();
      }, 1000);
    }
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    clearInterval(this.timer);
  };

  _proto.handleAccept = function handleAccept() {
    toneManager.stopAll();

    if (this.props.session.state === SessionState.Initial) {
      this.props.session.accept({
        sessionDescriptionHandlerOptions: {
          constraints: {
            audio: true,
            video: false
          }
        }
      });
    }

    this.props.acceptCall(this.props.session);
  };

  _proto.handleAutoAnswer = function handleAutoAnswer() {
    console.log('\n\n\n ************ handleAutoAnswer ********** \n\n\n');

    if (this.props.session.state === SessionState.Initial) {
      this.handleAccept();
    }

    clearInterval(this.timer);
  };

  _proto.handleDecline = function handleDecline() {
    toneManager.stopAll();

    if (this.props.session.state !== SessionState.Terminated && this.props.session.state !== SessionState.Terminating) {
      this.props.session.reject();
    }

    this.props.declineCall(this.props.session);
  };

  _proto.render = function render() {
    var _this2 = this;

    var props = this.props;
    return createElement("div", {
      className: 'modal fade calling-popup fadeIn show',
      id: 'calling',
      tabIndex: -1,
      role: 'dialog',
      "aria-labelledby": 'exampleModalLabel',
      "aria-hidden": 'true',
      style: {
        display: 'block'
      }
    }, createElement("div", {
      className: 'modal-dialog',
      role: 'document'
    }, createElement("div", {
      className: 'modal-content'
    }, createElement("div", {
      className: 'modal-body'
    }, createElement("div", {
      className: 'calling-sec'
    }, createElement("div", {
      className: 'calling-personImg'
    }, createElement(Avatar, {
      name: props.session.remoteIdentity.displayName,
      round: true
    })), createElement("h3", {
      className: 'calling-personName'
    }, props.session.remoteIdentity.uri.normal.user + " - " + props.session.remoteIdentity._displayName), createElement("ul", {
      className: 'list-unstyled mb-0 calling-options'
    }, createElement("li", {
      className: 'call-receive'
    }, createElement("a", {
      href: 'javascript:void(0)',
      onClick: function onClick() {
        return _this2.handleAccept();
      }
    }, createElement("span", {
      className: 'fa-icon rv-phone-call'
    }))), createElement("li", {
      className: 'call-reject'
    }, createElement("a", {
      href: 'javascript:void(0)',
      onClick: function onClick() {
        return _this2.handleDecline();
      }
    }, createElement("span", {
      className: 'fa-icon rv-phone-down'
    })))), createElement("audio", {
      id: 'ringtone',
      loop: true
    }, createElement("source", {
      src: ring,
      type: 'audio/mpeg'
    }), ' '))))));
  };

  return Incoming;
}(Component);

var mapStateToProps$6 = function mapStateToProps(state) {
  return {
    stateChanged: state.sipSessions.stateChanged
  };
};

var actions$6 = {
  acceptCall: acceptCall,
  declineCall: declineCall
};
var Incoming$1 = connect(mapStateToProps$6, actions$6)(Incoming);

var getSessions = function getSessions(sessions, phoneConfig, attendedTransfers, incomingCalls) {
  var elements = [];

  for (var session in sessions) {
    if (attendedTransfers.includes(session)) continue;

    if (incomingCalls.includes(session)) {
      if (Object.keys(sessions).length >= phoneConfig.sessionsLimit + incomingCalls.length) {
        console.log('Unable to create more sessions...');
        console.log('Check your phoneConfig.sessionsLimit option!');
      } else {
        elements.push(createElement(Incoming$1, {
          session: sessions[session],
          key: session,
          autoanswer: phoneConfig.autoAnswer
        }));
      }
    } else {
      elements.push(createElement(Phone$1, {
        session: sessions[session],
        key: session,
        phoneConfig: phoneConfig
      }));
    }
  }

  return elements;
};

var PhoneSessions = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(PhoneSessions, _React$Component);

  function PhoneSessions() {
    return _React$Component.apply(this, arguments) || this;
  }

  var _proto = PhoneSessions.prototype;

  _proto.render = function render() {
    return createElement(Fragment, null, getSessions(this.props.sessions, this.props.phoneConfig, this.props.attendedTransfers, this.props.incomingCalls));
  };

  return PhoneSessions;
}(Component);

var mapStateToProps$7 = function mapStateToProps(state) {
  return {
    sessions: state.sipSessions.sessions,
    incomingCalls: state.sipSessions.incomingCalls,
    attendedTransfers: state.sipSessions.attendedTransfers
  };
};

var PS = connect(mapStateToProps$7)(PhoneSessions);

var styles$3 = {"dialpadPopup":"_3nFSN","modalDialog":"_1iru9","modalContent":"_37Glu","modalBody":"_1FZqD","dropdown-menu":"_24xr2","dropdownItem":"_1RkgD","dialpadHeader":"_19XK1","close":"_DIvxE","selectionWithIcon":"_2xqZc","selectionWithIcon__block":"_3ZQHG","customSelection":"_1XV6f","formControl":"_2_GNa","dropdown-toggle":"_AD1in","iconBox":"_2jlvW","faIcon":"_269nS","dialpadNumber":"_2kwYR","remove-margin":"_3A7ar","dialpadValues":"_v6-hH","alpha":"_1YUqL","padOptions":"_2idDP","message":"_2dN9S","voicemail":"_TI7jS","callBtn":"_1BgEb","arrow-icon":"_3sPtJ","dropdown-item":"_PLzy0","volumeHeadphone":"_2JH6J","dropdown":"_3F5_P","volumeDropdown":"_vF1qQ","dropdownMenu":"_MOp8r","range-slider":"_3Pyio","hide-this":"_3zde9","contactsLists":"_E9tUc","contactsLists__options":"_2llkg","contactsLists__img":"_R1ybx","contactsLists__name":"_1ehSI","contactsLists__search":"_D3wow","btn":"_1PCmk","form-control":"_2f830","contactsLists__view":"_7C1KH","tabContent":"_2Q7JF","nav-tabs":"_3Ofny","nav-item":"_2v4X7","nav-link":"_3Dwm1","active":"_1N_eP","groupContacts":"_2R5J7","accordion":"_3m2fP","card":"_1q7t6","card-head":"_3gTRS","card-body":"_1VfZB","voicemailSec":"_2b2eC","voicemailSec__options__main":"_3RmbX","voicemailSec__control":"_2MWGe","more-detail":"_1YADv","endCall":"_j2Jfc","icon-box":"_iM1kV","fa-icon":"_1HNuN"};

var callIcon = require('./assets/settings-24px.svg');

var callIconLarge = require('./assets/call-large-40px.svg');

var Dialstring = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(Dialstring, _React$Component);

  function Dialstring() {
    var _this;

    _this = _React$Component.apply(this, arguments) || this;
    _this.state = {
      currentDialString: '',
      number: '',
      show: true
    };
    _this.numbersWithLetters = {
      1: '',
      2: 'abc',
      3: 'def',
      4: 'ghi',
      5: 'jkl',
      6: 'mno',
      7: 'pqrs',
      8: 'tuv',
      9: 'wxyz'
    };

    _this.handleClickNumber = function (event) {
      event.preventDefault();

      _this.setNumber(_this.state.number + event.target.getAttribute('data-number'));
    };

    return _this;
  }

  var _proto = Dialstring.prototype;

  _proto.handleDial = function handleDial() {
    var sessionsActive = Object.keys(this.props.sessions).length;
    var attendedTransferActive = this.props.attendedTransfersList.length;
    var sessionDiff = sessionsActive - attendedTransferActive;

    if (sessionDiff >= this.props.phoneConfig.sessionsLimit) {
      this.props.sessionsLimitReached();
    } else {
      if (this.props.appConfig.mode === 'strict') {
        this.props.sipAccount.makeCall(this.props.phoneConfig.defaultDial);
      }

      if (!this.checkDialstring()) {
        this.props.sipAccount.makeCall("" + this.state.currentDialString);
      }
    }
  };

  _proto.checkDialstring = function checkDialstring() {
    return this.state.currentDialString.length === 0;
  };

  _proto.setNumber = function setNumber(number) {
    this.setState({
      number: this.state.number + number
    });
  };

  _proto.render = function render() {
    var _this2 = this;

    var props = this.props;

    if (props.appConfig.mode.includes('strict') && props.started === true) {
      return createElement("div", {
        className: styles$3.dialstringContainerStrict
      }, createElement("button", {
        className: styles$3.dialButtonStrict,
        onClick: function onClick() {
          return _this2.handleDial();
        }
      }, createElement("img", {
        src: callIconLarge,
        className: 'callIconLarge'
      })));
    } else if (props.appConfig.mode.includes('strict')) {
      return null;
    } else {
      return createElement("div", {
        className: styles$3.dialstringContainer
      }, createElement("input", {
        className: styles$3.dialInput,
        onKeyPress: function onKeyPress(e) {
          if (e.key === 'Enter') {
            _this2.handleDial();

            e.preventDefault();
          }
        },
        placeholder: 'Enter the number to call',
        onChange: function onChange(e) {
          return _this2.setState({
            currentDialString: e.target.value
          });
        }
      }), createElement("button", {
        className: styles$3.dialButton,
        disabled: this.checkDialstring(),
        onClick: function onClick() {
          return _this2.handleDial();
        }
      }, createElement("img", {
        src: callIcon,
        className: 'callIcon'
      })));
    }
  };

  return Dialstring;
}(Component);

var mapStateToProps$8 = function mapStateToProps(state) {
  return {
    sipAccount: state.sipAccounts.sipAccount,
    sessions: state.sipSessions.sessions,
    started: state.config.appConfig.started,
    attendedTransfersList: state.sipSessions.attendedTransfers
  };
};

var actions$7 = {
  sessionsLimitReached: sessionsLimitReached
};
var D = connect(mapStateToProps$8, actions$7)(Dialstring);

var sipSessions = function sipSessions(state, action) {
  var _extends2, _extends3, _extends4;

  if (state === void 0) {
    state = {
      sessions: {},
      incomingCalls: [],
      stateChanged: 0,
      onHold: [],
      attendedTransfers: []
    };
  }

  var type = action.type,
      payload = action.payload;

  switch (type) {
    case INCOMING_CALL:
      console.log('Incoming call');
      return _extends(_extends({}, state), {}, {
        sessions: _extends(_extends({}, state.sessions), {}, (_extends2 = {}, _extends2[payload.id] = payload, _extends2)),
        incomingCalls: [].concat(state.incomingCalls, [payload.id])
      });

    case NEW_SESSION:
      console.log('New session added');
      console.log('session payload', payload);
      return _extends(_extends({}, state), {}, {
        sessions: _extends(_extends({}, state.sessions), {}, (_extends3 = {}, _extends3[payload.id] = payload, _extends3))
      });

    case NEW_ATTENDED_TRANSFER:
      return _extends(_extends({}, state), {}, {
        sessions: _extends(_extends({}, state.sessions), {}, (_extends4 = {}, _extends4[payload.id] = payload, _extends4)),
        attendedTransfers: [].concat(state.attendedTransfers, [payload.id])
      });

    case SIPSESSION_ATTENDED_TRANSFER_CANCEL:
    case SIPSESSION_ATTENDED_TRANSFER_FAIL:
      {
        var newAttendedTransfers = [].concat(state.attendedTransfers).filter(function (id) {
          return id !== payload.id;
        });
        return _extends(_extends({}, state), {}, {
          attendedTransfers: newAttendedTransfers
        });
      }

    case ACCEPT_CALL:
      {
        var acceptedIncoming = [].concat(state.incomingCalls).filter(function (id) {
          return id !== payload.id;
        });
        return _extends(_extends({}, state), {}, {
          incomingCalls: acceptedIncoming
        });
      }

    case DECLINE_CALL:
      {
        var declinedIncoming = [].concat(state.incomingCalls).filter(function (id) {
          return id !== payload.id;
        });

        var declinedSessions = _extends({}, state.sessions);

        delete declinedSessions[payload.id];
        return _extends(_extends({}, state), {}, {
          incomingCalls: declinedIncoming,
          sessions: declinedSessions
        });
      }

    case SIPSESSION_STATECHANGE:
      {
        return _extends(_extends({}, state), {}, {
          stateChanged: state.stateChanged + 1
        });
      }

    case CLOSE_SESSION:
      {
        var closedIncoming = [].concat(state.incomingCalls).filter(function (id) {
          return id !== payload;
        });

        var newSessions = _extends({}, state.sessions);

        delete newSessions[payload];
        var endHold = [].concat(state.onHold).filter(function (id) {
          return id !== payload;
        });
        return _extends(_extends({}, state), {}, {
          sessions: newSessions,
          incomingCalls: closedIncoming,
          onHold: endHold
        });
      }

    case SIPSESSION_HOLD_REQUEST:
      {
        return _extends(_extends({}, state), {}, {
          onHold: [].concat(state.onHold, [payload])
        });
      }

    case SIPSESSION_UNHOLD_REQUEST:
      {
        var newHold = [].concat(state.onHold).filter(function (id) {
          return id !== payload;
        });
        return _extends(_extends({}, state), {}, {
          onHold: newHold
        });
      }

    default:
      return state;
  }
};

var sipAccounts = function sipAccounts(state, action) {
  if (state === void 0) {
    state = {
      sipAccount: null,
      userAgent: null,
      status: ''
    };
  }

  var type = action.type,
      payload = action.payload;

  switch (type) {
    case NEW_ACCOUNT:
      return _extends(_extends({}, state), {}, {
        sipAccount: action.payload
      });

    case NEW_USERAGENT:
      return _extends(_extends({}, state), {}, {
        userAgent: payload
      });

    default:
      return state;
  }
};

var device = function device(state, action) {
  if (state === void 0) {
    state = {
      audioInput: [],
      audioOutput: [],
      primaryAudioOutput: 'default',
      primaryAudioInput: 'default',
      sinkId: true
    };
  }

  var type = action.type,
      payload = action.payload;

  switch (type) {
    case AUDIO_INPUT_DEVICES_DETECTED:
      return _extends(_extends({}, state), {}, {
        audioInput: payload
      });

    case AUDIO_OUTPUT_DEVICES_DETECTED:
      return _extends(_extends({}, state), {}, {
        audioOutput: payload
      });

    case SET_PRIMARY_OUTPUT:
      return _extends(_extends({}, state), {}, {
        primaryAudioOutput: payload
      });

    case SET_PRIMARY_INPUT:
      return _extends(_extends({}, state), {}, {
        primaryAudioInput: payload
      });

    case AUDIO_SINKID_NOT_ALLOWED:
      return _extends(_extends({}, state), {}, {
        sinkId: false
      });

    default:
      return state;
  }
};

var config = function config(state, action) {
  if (state === void 0) {
    state = {
      uri: '',
      password: '',
      phoneConfig: {},
      appConfig: {
        mode: '',
        started: false,
        appSize: ''
      }
    };
  }

  switch (action.type) {
    case SET_PHONE_CONFIG:
      return _extends(_extends({}, state), {}, {
        phoneConfig: action.payload
      });

    case SET_CREDENTIALS:
      return _extends(_extends({}, state), {}, {
        uri: action.payload.uri,
        password: action.payload.password
      });

    case SET_APP_CONFIG:
      return _extends(_extends({}, state), {}, {
        appConfig: action.payload
      });

    case STRICT_MODE_SHOW_CALL_BUTTON:
      if (state.appConfig.mode === 'strict') {
        return _extends(_extends({}, state), {}, {
          appConfig: _extends(_extends({}, state.appConfig), {}, {
            mode: 'strict',
            started: true
          })
        });
      }

      return state;

    case STRICT_MODE_HIDE_CALL_BUTTON:
      if (state.appConfig.mode === 'strict') {
        return _extends(_extends({}, state), {}, {
          appConfig: _extends(_extends({}, state.appConfig), {}, {
            mode: 'strict',
            started: false
          })
        });
      }

      return state;

    default:
      return state;
  }
};

var ADD_LOG = 'ADD_LOG';
var GET_LOGS = 'GET_LOGS';

var callLogs = function callLogs(state, action) {
  if (state === void 0) {
    state = {
      logs: []
    };
  }

  var type = action.type,
      payload = action.payload;

  switch (type) {
    case ADD_LOG:
      return _extends(_extends({}, state), {}, {
        logs: [].concat(state.logs, [payload])
      });

    case GET_LOGS:
      return _extends(_extends({}, state), {}, {
        logs: payload
      });

    default:
      return state;
  }
};

var reducers = combineReducers({
  sipAccounts: sipAccounts,
  sipSessions: sipSessions,
  device: device,
  config: config,
  callLogs: callLogs
});

var middleware = [thunk];
var persistConfig = {
  key: 'root',
  storage: storage,
  whitelist: ['device']
};
var persistedReducer = persistReducer(persistConfig, reducers);
var defaultStore = createStore(persistedReducer, composeWithDevTools(applyMiddleware.apply(void 0, middleware)));
var persistor = persistStore(defaultStore);

var phoneStore = defaultStore;
var ReactSipPhone = function ReactSipPhone(_ref) {
  var name = _ref.name,
      _ref$width = _ref.width,
      width = _ref$width === void 0 ? 100 : _ref$width,
      _ref$height = _ref.height,
      height = _ref$height === void 0 ? 20 : _ref$height,
      phoneConfig = _ref.phoneConfig,
      sipConfig = _ref.sipConfig,
      appConfig = _ref.appConfig,
      sipCredentials = _ref.sipCredentials,
      _ref$containerStyle = _ref.containerStyle,
      containerStyle = _ref$containerStyle === void 0 ? {} : _ref$containerStyle;
  return createElement(Provider, {
    store: phoneStore
  }, createElement(PersistGate, {
    loading: null,
    persistor: persistor
  }, createElement(SipWrapper$1, {
    sipConfig: sipConfig,
    sipCredentials: sipCredentials,
    phoneConfig: phoneConfig,
    appConfig: appConfig
  }, createElement("div", {
    className: styles.container,
    style: _extends(_extends({}, containerStyle), {}, {
      width: width + "%",
      height: height + "%"
    })
  }, createElement(Status$1, {
    phoneConfig: phoneConfig,
    appConfig: appConfig,
    name: name
  }), phoneConfig.disabledFeatures.includes('dialstring') ? null : createElement(D, {
    sipConfig: sipConfig,
    phoneConfig: phoneConfig,
    appConfig: appConfig
  }), createElement(PS, {
    phoneConfig: phoneConfig
  }), createElement("audio", {
    id: 'tone',
    autoPlay: true
  })))));
};

export { ReactSipPhone, phoneStore };
//# sourceMappingURL=index.modern.js.map
